---
title: "MTCS SS"
description: "Terraform compliance scanning for MTCS SS — assess for free, remediate with ComplyForm"
---

import { Badge } from '@astrojs/starlight/components';

<Badge text="Team" variant="caution" />
<Badge text="Government" variant="tip" />

**Issuing body:** [IMDA](https://www.imda.gov.sg)
**Jurisdiction:** Country — Asia-Pacific
**Countries:** SG


## Assessment

Assess your infrastructure against MTCS for free at any tier:

```bash
complyform assess --frameworks=mtcs
```

## Remediation

Requires Team tier or higher ($1,999/yr) for remediation.

```bash
complyform remediate --frameworks=mtcs
```

## Related Frameworks

- [IRAP](/frameworks/irap)
- [K-ISMS-P](/frameworks/k_isms_p)
- [OSPAR](/frameworks/ospar)
- [ISMAP](/frameworks/ismap)
